# coding: utf-8
"""
Пакет, упрощающий генерацию Browser-UI на основе ExtJS
с помошью python-кода
"""
